#!/bin/bash

# 检查权限
if [ "$(id -u)" != "0" ]; then
   echo "此脚本必须以root权限运行" 1>&2
   exit 1
fi

# 定义下载的URL和应用程序的名字
APP_URL="https://mirror.eh.cx/lrcapi/lrcapi"
APP_NAME="lrcapi"

# 定义应用程序的安装位置
INSTALL_DIR="/opt"

# 定义systemd服务文件的路径
SERVICE_FILE="/etc/systemd/system/${APP_NAME}.service"

# 从指定URL下载应用程序
echo "正在下载应用程序..."
curl -L $APP_URL -o $INSTALL_DIR/$APP_NAME

# 为应用程序设置可执行权限
chmod +x $INSTALL_DIR/$APP_NAME

# 创建一个新的systemd服务文件
echo "正在创建新的systemd服务文件..."
cat << EOF > $SERVICE_FILE
[Unit]
Description=My App

[Service]
ExecStart=$INSTALL_DIR/$APP_NAME
Restart=always
User=root
Group=root
Environment=PATH=/usr/bin:/usr/local/bin
Environment=NODE_ENV=production
WorkingDirectory=$INSTALL_DIR

[Install]
WantedBy=multi-user.target
EOF

# 刷新systemd，使其读取新的服务文件
echo "正在刷新systemd..."
systemctl daemon-reload

# 启动服务并设置为开机启动
echo "正在启动服务并设置为开机启动..."
systemctl start $APP_NAME
systemctl enable $APP_NAME

# 打印完成提示
echo "服务已成功启动并设置为开机启动！"